@@ -306,10 +306,10 @@ class LG_Error(Exception):
         # Propagate a possible ending "\n" into the format, from which the LG
         # error facility determine if this is a partial or a complete message.
         if msg[-1:] == "\n":      # a newline-ended complete message
-            _local_eol = "\n";
+            _local_eol = "\n"
             msg = msg[:-1]
         elif msg[-2:] == "\n\\":  # a newline-ended partial message
-            _local_eol = "";
+            _local_eol = ""
             msg = msg[:-1]
         else:
             _local_eol = ""       # a partial message
